MultiTanDataSource
==================

.. currentmodule:: toasty.multi_tan

.. autoclass:: MultiTanDataSource
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultiTanDataSource.compute_global_pixelization
      ~MultiTanDataSource.create_wtml
      ~MultiTanDataSource.generate_deepest_layer_numpy

   .. rubric:: Methods Documentation

   .. automethod:: compute_global_pixelization
   .. automethod:: create_wtml
   .. automethod:: generate_deepest_layer_numpy
